@@ -22,6 +22,9 @@ class Config(object):
 
     SERVER_API_BASE_URL = "http://127.0.0.1:5000/"
 
+    SESSION_COOKIE_HTTPONLY = True
+    SESSION_COOKIE_SAMESITE = "Lax"
+
     CFGI_MIN = "1d"
     CFGI_MAX = "12w"
 
@@ -35,6 +38,9 @@ class ConfigProduction(Config):
 
     SESSION_PROTECTION = "strong"
 
+    SESSION_COOKIE_SECURE = True
+    REMEMBER_COOKIE_SECURE = True
+
 
 class ConfigDevelopment(Config):
     DEBUG = True
@@ -45,6 +51,9 @@ class ConfigDevelopment(Config):
 
     SESSION_PROTECTION = "basic"
 
+    SESSION_COOKIE_SECURE = False
+    REMEMBER_COOKIE_SECURE = False
+
 
 class ConfigDocker(ConfigDevelopment):
     SERVER_API_BASE_URL = "http://172.19.10.2:5000/"
