@@ -73,11 +73,14 @@ SYMBOLS_PER_EXCHANGE.append(
                 ("VET", "USDT"),
                 ("NANO", "USDT"),
                 ("ONT", "USDT"),
+                ("LINK", "USDT"),
+                ("LINK", "BTC"),
                 ("HBAR", "USDT"),
                 ("HBAR", "BTC"),
                 ("LTO", "USDT"),
                 ("LTO", "BTC"),
-                ("LTO", "BNB"),
+                ("FTM", "USDT"),
+                ("FTM", "BTC"),
                 ("REN", "USDT"),
                 ("REN", "BTC"),
                 ("KNC", "USDT"),
@@ -121,7 +124,6 @@ SYMBOLS_PER_EXCHANGE.append(
             "pairs": [
                 ("LTO", "USDT"),
                 ("LTO", "BTC"),
-                ("LTO", "ETH"),
                 ("BTMX", "USDT"),
             ],
             "single_request": True,
@@ -131,7 +133,16 @@ SYMBOLS_PER_EXCHANGE.append(
 
 # IDEX
 SYMBOLS_PER_EXCHANGE.append(
-    {IDEX: {"pairs": [("LTO", "ETH"), ("LQD", "ETH"), ("IDEX", "ETH"),]}}
+    {
+        IDEX: {
+            "pairs": [
+                ("LTO", "ETH"),
+                ("LQD", "ETH"),
+                ("IDEX", "ETH"),
+                ("CARD", "ETH"),
+            ]
+        }
+    }
 )
 
 # OKCoin
@@ -194,28 +205,30 @@ SYMBOLS_PER_EXCHANGE.append({SWITCHEO: {"pairs": [], "single_request": True,}})
 
 
 EXCHANGES_AND_PAIRS_OF_REFERENCE = {
-    "BTC": {"pair": "USDT", "name": BINANCE,},
-    "ETH": {"pair": "USDT", "name": BINANCE,},
-    "LTC": {"pair": "USDT", "name": BINANCE,},
-    "BNB": {"pair": "USDT", "name": BINANCE,},
-    "XRP": {"pair": "USDT", "name": BINANCE,},
-    "XLM": {"pair": "USDT", "name": BINANCE,},
-    "XMR": {"pair": "USDT", "name": BINANCE,},
-    "ADA": {"pair": "USDT", "name": BINANCE,},
-    "VET": {"pair": "USDT", "name": BINANCE,},
-    "ICX": {"pair": "USDT", "name": BINANCE,},
-    "XTZ": {"pair": "USDT", "name": BINANCE,},
-    "NANO": {"pair": "USDT", "name": BINANCE,},
-    "ONT": {"pair": "USDT", "name": BINANCE,},
-    "HBAR": {"pair": "USDT", "name": BINANCE,},
+    "BTC": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "ETH": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "LTC": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "BNB": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "XRP": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "XLM": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "XMR": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "ADA": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "VET": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "ICX": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "XTZ": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "NANO": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "ONT": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "LINK": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "HBAR": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
     "BTMX": {"pair": "USDT", "name": BITMAX,},
-    "LTO": {"pair": "USDT", "name": BINANCE,},
-    "KNC": {"pair": "USDT", "name": BINANCE,},
-    "LEND": {"pair": "USDT", "name": BINANCE,},
-    "REN": {"pair": "USDT", "name": BINANCE,},
-    "IDEX": {"pair": "ETH", "name": IDEX,},
-    "LQD": {"pair": "ETH", "name": BILAXY,},
-    "CARD": {"pair": "ETH", "name": HOTBIT,},
+    "LTO": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "FTM": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "KNC": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "LEND": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "REN": {"pair": "USDT", "name": BINANCE, "market_depth": BINANCE},
+    "IDEX": {"pair": "ETH", "name": IDEX, "market_depth": IDEX},
+    "LQD": {"pair": "ETH", "name": BILAXY, "market_depth": IDEX},
+    "CARD": {"pair": "ETH", "name": HOTBIT, "market_depth": IDEX},
     "EWT": {"pair": "ETH", "name": LIQUID,},
 }
 
