@@ -15,17 +15,15 @@ from celery.task import task
 from celery.exceptions import Ignore
 from celery import states
 from xtcryptosignals.common.utils import use_mongodb
-from xtcryptosignals.tasks import settings as s
 from xtcryptosignals.tasks.models.cfgi import CFGI
+from xtcryptosignals.tasks import settings as s
 
 
 red = redis.Redis.from_url(s.BROKER_URL)
 
 
 @task(bind=True)
-@use_mongodb(
-    db=s.MONGODB_NAME, host=s.MONGODB_HOST, port=s.MONGODB_PORT,
-)
+@use_mongodb(db=s.MONGODB_NAME, host=s.MONGODB_HOST, port=s.MONGODB_PORT)
 def update(self):
     logger = self.get_logger()
 
