@@ -20,9 +20,9 @@ from xtcryptosignals.common.models import (
     DocumentValidation,
     _set_timestamp,
 )
-from xtcryptosignals.tasks import settings as s
 from xtcryptosignals.tasks.models.history import History
 from xtcryptosignals.tasks.utils import convert_to_seconds
+from xtcryptosignals.tasks import settings as s
 
 
 red = redis.Redis.from_url(s.BROKER_URL)
@@ -86,6 +86,9 @@ def _set_history(ticker):
             history_object.price_usdt = ticker["price_usdt"]
 
         if not ticker._exists_row_offset(model_history, offset=x):
+            row = ticker.to_dict()
+            key = s.REDIS_KEY_TICKER.format(**row, frequency=x)
+            red.set(key, row["price"])
             history_object.save()
         else:
             _set_timestamp(history_object)
@@ -94,11 +97,6 @@ def _set_history(ticker):
         ticker.history_list_dicts.append(history_object.to_dict(frequency=x))
 
 
-def _save_ticker_in_redis(ticker):
-    row = ticker.to_dict()
-    red.set(s.REDIS_KEY_TICKER.format(**row), row["price"])
-
-
 class Ticker(DocumentValidation):
     symbol = StringField(required=True)
     source = StringField(required=True)
@@ -115,10 +113,7 @@ class Ticker(DocumentValidation):
     opened_on = DateTimeField()
     closed_on = DateTimeField()
 
-    _pre_save_hooks = (
-        _set_history,
-        _save_ticker_in_redis,
-    )
+    _pre_save_hooks = (_set_history,)
 
     meta = {
         "collection": "ticker",
@@ -126,7 +121,7 @@ class Ticker(DocumentValidation):
     }
 
     def to_dict(self):
-        e = super(Ticker, self).to_dict().copy()
+        e = super().to_dict().copy()
         for k in e:
             if k in (
                 "price",
