@@ -8,9 +8,11 @@ __maintainer__ = "Paulo Antunes"
 __email__ = "pjmlantunes@gmail.com"
 
 
+import os
 import json
 import redis
 import hashlib
+import telegram
 from datetime import timedelta
 from celery.task import task
 from celery.exceptions import Ignore
@@ -28,6 +30,8 @@ from xtcryptosignals.tasks import settings as s
 
 red = redis.Redis.from_url(s.BROKER_URL)
 
+PATH_LOGOS = f"{os.path.dirname(os.path.realpath(__file__))}/../client/static/imgs/logos/"
+
 
 @task(bind=True)
 @use_mongodb(db=s.MONGODB_NAME, host=s.MONGODB_HOST, port=s.MONGODB_PORT)
@@ -60,13 +64,13 @@ def update(self):
 
         if price < 1:
             message_templ = (
-                '<a href="/ticker/source/{ticker}/10s">{ticker}'
+                '<a href="{domain}/ticker/source/{ticker}/10s">{ticker}'
                 "</a> {metric} is {direction} {change}% within "
                 "{interval}. Current Price is {price:,.4f} USDT."
             )
         else:
             message_templ = (
-                '<a href="/ticker/source/{ticker}/10s">{ticker}'
+                '<a href="{domain}/ticker/source/{ticker}/10s">{ticker}'
                 "</a> {metric} is {direction} {change}% within "
                 "{interval}. Current Price is {price:,.2f} USDT."
             )
@@ -93,7 +97,8 @@ def update(self):
             )
         )
 
-        message = message_templ.format(
+        message_web = message_templ.format(
+            domain=s.WEBSITE_ADDRESS,
             ticker=obj_history["ticker"],
             metric=notif.metric.capitalize(),
             direction=direction,
@@ -102,12 +107,14 @@ def update(self):
             price=price,
         )
 
-        key = "{}{}".format(notif.user.pk, message)
+        key = "{}{}".format(notif.user.pk, message_web)
         hash_object = hashlib.md5(key.encode())
         redis_key = hash_object.hexdigest()
 
         if red.get(redis_key):
-            logger.warning("Already sent notif. to {}".format(notif.user.pk))
+            logger.warning(
+                "Already sent notifications to {}".format(notif.user.pk)
+            )
             continue
 
         red.setex(
@@ -116,16 +123,19 @@ def update(self):
             time=timedelta(seconds=convert_to_seconds(notif.interval)),
         )
 
-        notif_kwargs = dict(
-            coin_token=obj_history["ticker"], message=message, user=notif.user,
+        notification_kwargs = dict(
+            coin_token=obj_history["ticker"],
+            message=message_web,
+            user=notif.user,
         )
         if notif.metric == "price":
-            notif_kwargs.update(is_positive=(direction is "up"))
+            notification_kwargs.update(is_positive=(direction is "up"))
 
-        Notification(**notif_kwargs).save()
+        Notification(**notification_kwargs).save()
 
-        message = message.replace(
-            '<a href="/ticker/source/{ticker}/10s">{ticker}</a>'.format(
+        message_push_notification = message_web.replace(
+            '<a href="{domain}/ticker/source/{ticker}/10s">{ticker}</a>'.format(
+                domain=s.WEBSITE_ADDRESS,
                 ticker=obj_history["ticker"]
             ),
             obj_history["ticker"],
@@ -133,19 +143,21 @@ def update(self):
 
         try:
             try:
-                logger.warning("Sending notif. to {}".format(notif.user.pk))
+                logger.warning(
+                    "Sending web notification to {}".format(notif.user.pk)
+                )
                 webpush(
                     subscription_info=notif.user.metadata["subscription"],
                     data=json.dumps(
                         dict(
                             title="XTCryptoSignals",
-                            message=message,
+                            message=message_push_notification,
                             url="{}/ticker/{symbol}/{frequency}".format(
                                 s.WEBSITE_ADDRESS, **obj_history
                             ),
                             icon="{}{ticker}.png".format(
                                 s.STATIC_COINS_TOKENS_LOGOS_FOLDER,
-                                **obj_history
+                                **obj_history,
                             ),
                         )
                     ),
@@ -162,8 +174,24 @@ def update(self):
                         extra.message,
                     )
         except Exception as error:
-            logger.error("notifications error: {}".format(str(error)))
+            logger.error("web notification error: {}".format(str(error)))
+            self.update_state(state=states.FAILURE, meta=str(error))
+            raise Ignore()
+
+        heart = "💚" if direction is "up" else "❤️"
+        try:
+            logger.warning("Sending telegram notification")
+            bot = telegram.Bot(token=s.TELEGRAM_BOT_TOKEN)
+            with open(
+                f"{PATH_LOGOS}{obj_history['ticker']}@128.png", "rb",
+            ) as photo:
+                bot.send_photo(
+                    chat_id=s.TELEGRAM_GROUP_CHAT_ID,
+                    photo=photo,
+                    caption=f"{heart} {message_web}",
+                    parse_mode=telegram.ParseMode.HTML,
+                )
+        except Exception as error:
+            logger.error("telegram notification error: {}".format(str(error)))
             self.update_state(state=states.FAILURE, meta=str(error))
             raise Ignore()
-        finally:
-            pass
